#version 330 core
layout(location = 0) out vec4 FragColor;
layout(location = 1) out vec4 BrightColor;

in VS_OUT{
	vec3 FragPos;
	vec3 Normal;
	vec2 TexCoords;
} fs_in;

struct Light {
	vec3 Position;
	vec3 Color;
};

uniform int lightCount;
uniform Light lights[64];
uniform sampler2D texture_diffuse1;
uniform sampler2D texture_diffuse2;
uniform vec3 viewPos;

void main()
{
	vec3 diffuse = texture(texture_diffuse1, fs_in.TexCoords).rgb;
	vec3 lightmap = texture(texture_diffuse2, fs_in.TexCoords).rgb;
	lightmap = vec3(lightmap.r + lightmap.g + lightmap.b) / 3.0;

	vec3 color = diffuse * lightmap;

	vec3 normal = normalize(fs_in.Normal);
	// ambient
	vec3 ambient = 1.0 * color;
	// lighting
	vec3 lighting = vec3(0.0);
	vec3 viewDir = normalize(viewPos - fs_in.FragPos);
	for (int i = 0; i < lightCount; i++)
	{
		// diffuse
		vec3 lightDir = normalize(lights[i].Position - fs_in.FragPos);
		float diff = max(dot(lightDir, normal), 0.0);
		vec3 result = lights[i].Color * diff * color;
		// attenuation (use quadratic as we have gamma correction)
		float distance = length(fs_in.FragPos - lights[i].Position);
		result *= 1.0 / (distance * distance);
		lighting += result;

	}
	vec3 result = ambient + lighting;
	// check whether result is higher than some threshold, if so, output as bloom threshold color
	float brightness = dot(result, vec3(0.2, 0.2, 0.2));
	
	if (brightness > 1.0)
		BrightColor = vec4(result, 1.0);
	else
		BrightColor = vec4(0.0, 0.0, 0.0, 1.0);

	FragColor = vec4(result, 1.0);
}